from ... pyaz_utils import _call_az
from . import akamai


def list(account_name, resource_group):
    '''
    List all the streaming endpoints within an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-endpoint list", locals())


def start(account_name, name, resource_group, no_wait=None):
    '''
    Start a streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az ams streaming-endpoint start", locals())


def stop(account_name, name, resource_group, no_wait=None):
    '''
    Stop a streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az ams streaming-endpoint stop", locals())


def create(account_name, name, resource_group, scale_units, auto_start=None, availability_set_name=None, cdn_profile=None, cdn_provider=None, client_access_policy=None, cross_domain_policy=None, custom_host_names=None, description=None, ips=None, max_cache_age=None, no_wait=None, tags=None):
    '''
    Create a streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scale_units -- The number of scale units for Premium StreamingEndpoints. For Standard StreamingEndpoints, set this value to 0. Use the Scale operation to adjust this value for Premium StreamingEndpoints.

    Optional Parameters:
    - auto_start -- The flag indicates if the resource should be automatically started on creation.
    - availability_set_name -- The name of the AvailabilitySet used with this StreamingEndpoint for high availability streaming. This value can only be set at creation time.
    - cdn_profile -- The CDN profile name.
    - cdn_provider -- The CDN provider name. Allowed values: StandardVerizon, PremiumVerizon, StandardAkamai.
    - client_access_policy -- The XML representing the clientaccesspolicy data used by Microsoft Silverlight and Adobe Flash. Use @{file} to load from a file. For further information about the XML structure please refer to documentation on https://docs.microsoft.com/rest/api/media/operations/crosssiteaccesspolicies
    - cross_domain_policy -- The XML representing the crossdomain data used by Silverlight. Use @{file} to load from a file. For further information about the XML structure please refer to documentation on https://docs.microsoft.com/rest/api/media/operations/crosssiteaccesspolicies
    - custom_host_names -- Space-separated list of custom host names for the streaming endpoint. Use "" to clear existing list.
    - description -- The streaming endpoint description.
    - ips -- Space-separated IP addresses for access control. Allowed IP addresses can be specified as either a single IP address (e.g. "10.0.0.1") or as an IP range using an IP address and a CIDR subnet mask (e.g. "10.0.0.1/22"). Use "" to clear existing list. If no IP addresses are specified any IP address will be allowed.
    - max_cache_age -- Max cache age.
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az ams streaming-endpoint create", locals())


def scale(account_name, name, resource_group, scale_units):
    '''
    Set the scale of a streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scale_units -- The number of scale units for Premium StreamingEndpoints. For Standard StreamingEndpoints, set this value to 0. Use the Scale operation to adjust this value for Premium StreamingEndpoints.
    '''
    return _call_az("az ams streaming-endpoint scale", locals())


def update(account_name, name, resource_group, add=None, cdn_profile=None, cdn_provider=None, client_access_policy=None, cross_domain_policy=None, custom_host_names=None, description=None, disable_cdn=None, force_string=None, ips=None, max_cache_age=None, no_wait=None, remove=None, set=None, tags=None):
    '''
    Update the details of a streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - cdn_profile -- The CDN profile name.
    - cdn_provider -- The CDN provider name. Allowed values: StandardVerizon, PremiumVerizon, StandardAkamai.
    - client_access_policy -- The XML representing the clientaccesspolicy data used by Microsoft Silverlight and Adobe Flash. Use @{file} to load from a file. For further information about the XML structure please refer to documentation on https://docs.microsoft.com/rest/api/media/operations/crosssiteaccesspolicies
    - cross_domain_policy -- The XML representing the crossdomain data used by Silverlight. Use @{file} to load from a file. For further information about the XML structure please refer to documentation on https://docs.microsoft.com/rest/api/media/operations/crosssiteaccesspolicies
    - custom_host_names -- Space-separated list of custom host names for the streaming endpoint. Use "" to clear existing list.
    - description -- The streaming endpoint description.
    - disable_cdn -- Use this flag to disable CDN for the streaming endpoint.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - ips -- Space-separated IP addresses for access control. Allowed IP addresses can be specified as either a single IP address (e.g. "10.0.0.1") or as an IP range using an IP address and a CIDR subnet mask (e.g. "10.0.0.1/22"). Use "" to clear existing list. If no IP addresses are specified any IP address will be allowed.
    - max_cache_age -- Max cache age.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az ams streaming-endpoint update", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-endpoint show", locals())


def delete(account_name, name, resource_group):
    '''
    Delete a streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-endpoint delete", locals())


def wait(account_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the streaming endpoint is met.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az ams streaming-endpoint wait", locals())




'''
Manage an Azure Service Fabric cluster.
'''
from ... pyaz_utils import _call_az
from . import client_certificate, durability, node, node_type, reliability, setting, upgrade_type


def show(cluster_name, resource_group):
    '''
    

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf cluster show", locals())


def list(resource_group=None):
    '''
    List cluster resources.

    Optional Parameters:
    - resource_group -- The resource group name
    '''
    return _call_az("az sf cluster list", locals())


def create(resource_group, certificate_file=None, certificate_output_folder=None, certificate_password=None, certificate_subject_name=None, cluster_name=None, cluster_size=None, location=None, parameter_file=None, secret_identifier=None, template_file=None, vault_name=None, vault_rg=None, vm_os=None, vm_password=None, vm_sku=None, vm_user_name=None):
    '''
    Create a new Azure Service Fabric cluster.

    Required Parameters:
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - certificate_file -- The existing certificate file path for the primary cluster certificate.
    - certificate_output_folder -- The folder of the new certificate file to be created.
    - certificate_password -- The password of the certificate file.
    - certificate_subject_name -- The subject name of the certificate to be created.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - cluster_size -- The number of nodes in the cluster. Default are 5 nodes
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - parameter_file -- The path to the template parameter file.
    - secret_identifier -- The existing Azure key vault secret URL
    - template_file -- The path to the template file.
    - vault_name -- Azure key vault name, it not given it will be the cluster resource group name
    - vault_rg -- Key vault resource group name, if not given it will be cluster resource group name
    - vm_os -- The Operating System of the VMs that make up the cluster.
    - vm_password -- The password of the Vm
    - vm_sku -- VM Sku
    - vm_user_name -- The user name for logging to Vm. Default will be adminuser
    '''
    return _call_az("az sf cluster create", locals())




'''
Manage the route server peering.
'''
from .... pyaz_utils import _call_az

def create(name, peer_asn, peer_ip, resource_group, routeserver, no_wait=None):
    '''
    Create a route server peering.

    Required Parameters:
    - name -- The name of the Route Server Peering
    - peer_asn -- Peer ASN. Its range is from 1 to 4294967295.
    - peer_ip -- Peer IP address.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network routeserver peering create", locals())


def update(name, resource_group, routeserver, add=None, force_string=None, peer_asn=None, peer_ip=None, remove=None, set=None):
    '''
    Update a route server peering.

    Required Parameters:
    - name -- The name of the Route Server Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - peer_asn -- Peer ASN. Its range is from 1 to 4294967295.
    - peer_ip -- Peer IP address.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network routeserver peering update", locals())


def delete(name, resource_group, routeserver, no_wait=None, yes=None):
    '''
    Delete a route server peering.

    Required Parameters:
    - name -- The name of the Route Server Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network routeserver peering delete", locals())


def show(name, resource_group, routeserver):
    '''
    Show a route server peering

    Required Parameters:
    - name -- The name of the Route Server Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.
    '''
    return _call_az("az network routeserver peering show", locals())


def wait(name, resource_group, routeserver, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the route server peering is met.

    Required Parameters:
    - name -- The name of the Route Server Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network routeserver peering wait", locals())


def list(resource_group, routeserver):
    '''
    List all route server peerings under a resource group.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.
    '''
    return _call_az("az network routeserver peering list", locals())


def list_learned_routes(name, resource_group, routeserver):
    '''
    List all routes the route server bgp connection has learned.

    Required Parameters:
    - name -- The name of the Route Server Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.
    '''
    return _call_az("az network routeserver peering list-learned-routes", locals())


def list_advertised_routes(name, resource_group, routeserver):
    '''
    List all routes the route server bgp connection is advertising to the specified peer.

    Required Parameters:
    - name -- The name of the Route Server Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - routeserver -- The name of the Route Server.
    '''
    return _call_az("az network routeserver peering list-advertised-routes", locals())




from .... pyaz_utils import _call_az
from . import rule


def list(gateway_name, resource_group):
    '''
    List URL path maps.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway url-path-map list", locals())


def show(gateway_name, name, resource_group):
    '''
    Get the details of a URL path map.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the URL path map.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway url-path-map show", locals())


def delete(gateway_name, name, resource_group, no_wait=None):
    '''
    Delete a URL path map.

    Required Parameters:
    - gateway_name -- The name of the application gateway.
    - name -- The name of the URL path map.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway url-path-map delete", locals())


def create(gateway_name, name, paths, resource_group, address_pool=None, default_address_pool=None, default_http_settings=None, default_redirect_config=None, default_rewrite_rule_set=None, http_settings=None, no_wait=None, redirect_config=None, rewrite_rule_set=None, rule_name=None, waf_policy=None):
    '''
    Create a URL path map.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the URL path map.
    - paths -- Space-separated list of paths to associate with the rule. Valid paths start and end with "/" (ex: "/bar/")
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - address_pool -- The name or ID of the backend address pool to use with the created rule.
    - default_address_pool -- The name or ID of the default backend address pool, if different from --address-pool.
    - default_http_settings -- The name or ID of the default HTTP settings, if different from --http-settings.
    - default_redirect_config -- The name or ID of the default redirect configuration.
    - default_rewrite_rule_set -- The name or ID of the default rewrite rule set, if different from --rewrite-rule-set.
    - http_settings -- The name or ID of the HTTP settings to use with the created rule.
    - no_wait -- Do not wait for the long-running operation to finish.
    - redirect_config -- The name or ID of the redirect configuration to use with the created rule.
    - rewrite_rule_set -- The name or ID of the rewrite rule set. If not specified, the default for the map will be used.
    - rule_name -- The name of the url-path-map rule.
    - waf_policy -- Name or ID of a Firewall Policy resource.
    '''
    return _call_az("az network application-gateway url-path-map create", locals())


def update(gateway_name, name, resource_group, add=None, default_address_pool=None, default_http_settings=None, default_redirect_config=None, default_rewrite_rule_set=None, force_string=None, no_wait=None, remove=None, set=None):
    '''
    Update a URL path map.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of the URL path map.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - default_address_pool -- The name or ID of the default backend address pool.
    - default_http_settings -- The name or ID of the default HTTP settings.
    - default_redirect_config -- The name or ID of the default redirect configuration.
    - default_rewrite_rule_set -- The name or ID of the default rewrite rule set.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network application-gateway url-path-map update", locals())




'''
Enables managing the Azure Defender plan for the subscription
'''
from ... pyaz_utils import _call_az

def list():
    '''
    Shows the Azure Defender plans for the subscription.
    '''
    return _call_az("az security pricing list", locals())


def show(name):
    '''
    Shows the Azure Defender plan for the subscription

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security pricing show", locals())


def create(name, tier):
    '''
    Updates the Azure defender plan for the subscription.

    Required Parameters:
    - name -- name of the resource to be fetched
    - tier -- pricing tier type
    '''
    return _call_az("az security pricing create", locals())




'''
Manage Synapse Spark sessions.
'''
from .... pyaz_utils import _call_az

def create(executor_size, executors, name, spark_pool_name, workspace_name, configuration=None, reference_files=None, tags=None):
    '''
    Create a Spark session.

    Required Parameters:
    - executor_size -- The executor size
    - executors -- The number of executors.
    - name -- The Spark session name.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - configuration -- The configuration of Spark session.
    - reference_files -- Additional files used for reference in the main definition file.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az synapse spark session create", locals())


def list(spark_pool_name, workspace_name, from_index=None, size=None):
    '''
    List all Spark sessions.

    Required Parameters:
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - from_index -- Optional parameter specifying which index the list should begin from.
    - size -- The size of the returned list.By default it is 20 and that is the maximum.
    '''
    return _call_az("az synapse spark session list", locals())


def show(livy_id, spark_pool_name, workspace_name):
    '''
    Get a Spark session.

    Required Parameters:
    - livy_id -- The id of the Spark session job.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az synapse spark session show", locals())


def cancel(livy_id, spark_pool_name, workspace_name, yes=None):
    '''
    Cancel a Spark session.

    Required Parameters:
    - livy_id -- The id of the Spark session job.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse spark session cancel", locals())


def reset_timeout(livy_id, spark_pool_name, workspace_name):
    '''
    Reset a Spark session timeout time.

    Required Parameters:
    - livy_id -- The id of the Spark session job.
    - spark_pool_name -- The name of the Spark pool.
    - workspace_name -- The name of the workspace.
    '''
    return _call_az("az synapse spark session reset-timeout", locals())




'''
Manage Data Lake Store account firewall rules.
'''
from .... pyaz_utils import _call_az

def create(account, end_ip_address, firewall_rule_name, start_ip_address, resource_group=None):
    '''
    Creates a firewall rule in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - end_ip_address -- None
    - firewall_rule_name -- None
    - start_ip_address -- None

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account firewall create", locals())


def update(account, firewall_rule_name, end_ip_address=None, resource_group=None, start_ip_address=None):
    '''
    Updates a firewall rule in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - firewall_rule_name -- The name of the firewall rule to update.

    Optional Parameters:
    - end_ip_address -- The end IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    - start_ip_address -- The start IP address for the firewall rule. This can be either ipv4 or ipv6. Start and End should be in the same protocol.
    '''
    return _call_az("az dls account firewall update", locals())


def list(account, resource_group=None):
    '''
    Lists firewall rules in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account firewall list", locals())


def show(account, firewall_rule_name, resource_group=None):
    '''
    Get the details of a firewall rule in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - firewall_rule_name -- The name of the firewall rule to retrieve.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account firewall show", locals())


def delete(account, firewall_rule_name, resource_group=None):
    '''
    Deletes a firewall rule in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - firewall_rule_name -- The name of the firewall rule to delete.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account firewall delete", locals())




from ... pyaz_utils import _call_az
from . import option


def create(account_name, name, policy_option_name, resource_group, alt_rsa_token_keys=None, alt_symmetric_token_keys=None, alt_x509_token_keys=None, ask=None, audience=None, clear_key_configuration=None, description=None, fair_play_pfx=None, fair_play_pfx_password=None, fp_playback_duration_seconds=None, fp_storage_duration_seconds=None, issuer=None, open_id_connect_discovery_document=None, open_restriction=None, play_ready_template=None, rental_and_lease_key_type=None, rental_duration=None, token_claims=None, token_key=None, token_key_type=None, token_type=None, widevine_template=None):
    '''
    Create a new content key policy.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The content key policy name.
    - policy_option_name -- The content key policy option name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - alt_rsa_token_keys -- Space-separated list of alternate rsa token keys.
    - alt_symmetric_token_keys -- Space-separated list of alternate symmetric token keys.
    - alt_x509_token_keys -- Space-separated list of alternate x509 certificate token keys.
    - ask -- The key that must be used as FairPlay Application Secret Key, which is a 32 character hex string.
    - audience -- The audience for the token.
    - clear_key_configuration -- Use Clear Key configuration, a.k.a AES encryption. It's intended for non-DRM keys.
    - description -- The content key policy description.
    - fair_play_pfx -- The filepath to a FairPlay certificate file in PKCS 12 (pfx) format (including private key).
    - fair_play_pfx_password -- The password encrypting FairPlay certificate in PKCS 12 (pfx) format.
    - fp_playback_duration_seconds -- Playback duration
    - fp_storage_duration_seconds -- Storage duration
    - issuer -- The token issuer.
    - open_id_connect_discovery_document -- The OpenID connect discovery document.
    - open_restriction -- Use open restriction. License or key will be delivered on every request. Not recommended for production environments.
    - play_ready_template -- JSON PlayReady license template. Use @{file} to load from a file.
    - rental_and_lease_key_type -- The rental and lease key type. Available values: Undefined, DualExpiry, PersistentUnlimited, PersistentLimited.
    - rental_duration -- The rental duration. Must be greater than or equal to 0.
    - token_claims -- Space-separated required token claims in '[key=value]' format.
    - token_key -- Either a string (for symmetric key) or a filepath to a certificate (x509) or public key (rsa). Must be used in conjunction with --token-key-type.
    - token_key_type -- The type of the token key to be used for the primary verification key. Allowed values: Symmetric, RSA, X509
    - token_type -- The type of token. Allowed values: Jwt, Swt.
    - widevine_template -- JSON Widevine license template. Use @{file} to load from a file.
    '''
    return _call_az("az ams content-key-policy create", locals())


def show(account_name, name, resource_group, with_secrets=None):
    '''
    Show an existing content key policy.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The content key policy name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - with_secrets -- Include secret values of the content key policy.
    '''
    return _call_az("az ams content-key-policy show", locals())


def delete(account_name, name, resource_group):
    '''
    Delete a content key policy.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The content key policy name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams content-key-policy delete", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the content key policies within an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - filter -- Restricts the set of items returned.
    - orderby -- Specifies the key by which the result collection should be ordered.
    - top -- Specifies a non-negative integer n that limits the number of items returned from a collection. The service returns the number of available items up to but not greater than the specified value n.
    '''
    return _call_az("az ams content-key-policy list", locals())


def update(account_name, name, resource_group, add=None, description=None, force_string=None, remove=None, set=None):
    '''
    Update an existing content key policy.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The content key policy name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - description -- The content key policy description.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az ams content-key-policy update", locals())




'''
Manage Azure Relay Service WCF Relay and Authorization Rule
'''
from ... pyaz_utils import _call_az
from . import authorization_rule


def create(name, namespace_name, relay_type, resource_group, requires_client_authorization=None, requires_transport_security=None, user_metadata=None):
    '''
    Create the Relay Service WCF Relay

    Required Parameters:
    - name -- Name of WCF Relay
    - namespace_name -- Name of Namespace
    - relay_type -- Relay type
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - requires_client_authorization -- Indicates whether client authorization is required
    - requires_transport_security -- Indicates whether transport security is required
    - user_metadata -- Endpoint metadata
    '''
    return _call_az("az relay wcfrelay create", locals())


def show(name, namespace_name, resource_group):
    '''
    shows the Relay Service WCF Relay Details

    Required Parameters:
    - name -- Name of WCF Relay
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az relay wcfrelay show", locals())


def list(namespace_name, resource_group):
    '''
    List the WCF Relay by Relay Service Namespace

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az relay wcfrelay list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Relay Service WCF Relay

    Required Parameters:
    - name -- Name of WCF Relay
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az relay wcfrelay delete", locals())


def update(name, namespace_name, resource_group, add=None, force_string=None, relay_type=None, remove=None, set=None, status=None, user_metadata=None):
    '''
    Updates existing Relay Service WCF Relay

    Required Parameters:
    - name -- Name of WCF Relay
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - relay_type -- Relay type
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - status -- Enumerates the possible values for the status of a messaging entity.
    - user_metadata -- Endpoint metadata
    '''
    return _call_az("az relay wcfrelay update", locals())




'''
Manage secrets.
'''
from ... pyaz_utils import _call_az

def list(id=None, include_managed=None, maxresults=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- Full URI of the Vault or HSM. If specified all other 'Id' arguments should be omitted.
    - include_managed -- Include managed secrets. Default: false
    - maxresults -- Maximum number of results to return in a page. If not specified, the service will return up to 25 results.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault secret list", locals())


def list_versions(id=None, maxresults=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- Id of the secret. If specified all other 'Id' arguments should be omitted.
    - maxresults -- Maximum number of results to return in a page. If not specified, the service will return up to 25 results.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault secret list-versions", locals())


def list_deleted(vault_name, id=None, maxresults=None):
    '''
    

    Required Parameters:
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - id -- Full URI of the Vault. If specified all other 'Id' arguments should be omitted.
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    '''
    return _call_az("az keyvault secret list-deleted", locals())


def set(name, vault_name, description=None, disabled=None, encoding=None, expires=None, file=None, not_before=None, secret_attributes=None, tags=None, value=None):
    '''
    Create a secret (if one doesn't exist) or update a secret in a KeyVault.

    Required Parameters:
    - name -- Name of the secret.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - description -- Description of the secret contents (e.g. password, connection string, etc)
    - disabled -- Create secret in disabled state.
    - encoding -- Source file encoding. The value is saved as a tag (`file-encoding=<val>`) and used during download to automatically encode the resulting file.
    - expires -- Expiration UTC datetime  (Y-m-d'T'H:M:S'Z').
    - file -- Source file for secret. Use in conjunction with '--encoding'
    - not_before -- Key not usable before the provided UTC datetime  (Y-m-d'T'H:M:S'Z').
    - secret_attributes -- ==SUPPRESS==
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - value -- Plain text secret value. Cannot be used with '--file' or '--encoding'
    '''
    return _call_az("az keyvault secret set", locals())


def set_attributes(content_type=None, enabled=None, expires=None, id=None, name=None, not_before=None, secret_attributes=None, tags=None, vault_name=None, version=None):
    '''
    

    Optional Parameters:
    - content_type -- Type of the secret value such as a password.
    - enabled -- Enable the secret.
    - expires -- Expiration UTC datetime  (Y-m-d'T'H:M:S'Z').
    - id -- Id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - not_before -- Key not usable before the provided UTC datetime  (Y-m-d'T'H:M:S'Z').
    - secret_attributes -- ==SUPPRESS==
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    - version -- The secret version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault secret set-attributes", locals())


def show(id=None, name=None, vault_name=None, version=None):
    '''
    

    Optional Parameters:
    - id -- Id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    - version -- The secret version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault secret show", locals())


def show_deleted(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- The recovery id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault secret show-deleted", locals())


def delete(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- Id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault secret delete", locals())


def purge(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- The recovery id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault secret purge", locals())


def recover(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- The recovery id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault secret recover", locals())


def download(file, encoding=None, id=None, name=None, vault_name=None, version=None):
    '''
    

    Required Parameters:
    - file -- File to receive the secret contents.

    Optional Parameters:
    - encoding -- Encoding of the secret. By default, will look for the 'file-encoding' tag on the secret. Otherwise will assume 'utf-8'.
    - id -- Id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    - version -- The secret version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault secret download", locals())


def backup(file, id=None, name=None, vault_name=None):
    '''
    

    Required Parameters:
    - file -- File to receive the secret contents.

    Optional Parameters:
    - id -- Id of the secret. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the secret. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault secret backup", locals())


def restore(file, vault_name):
    '''
    

    Required Parameters:
    - file -- File to receive the secret contents.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault secret restore", locals())




'''
Manage Azure API Management Named Values.
'''
from ... pyaz_utils import _call_az

def create(display_name, named_value_id, resource_group, service_name, secret=None, tags=None, value=None):
    '''
    Create an API Management Named Value.

    Required Parameters:
    - display_name -- Required. Unique name of NamedValue. It may contain only letters, digits, period, dash, and underscore characters.
    - named_value_id -- Identifier of the NamedValue.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - secret -- Determines whether the value is a secret and should be encrypted or not. Default value is false.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - value -- Required. Value of the NamedValue. Can contain policy expressions. It may not be empty or consist only of whitespace. This property will not be filled on GET operations! Use /listSecrets POST request to get the value.
    '''
    return _call_az("az apim nv create", locals())


def show(named_value_id, resource_group, service_name):
    '''
    Show details of an API Management Named Value.

    Required Parameters:
    - named_value_id -- Identifier of the NamedValue.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim nv show", locals())


def list(resource_group, service_name):
    '''
    List API Management Named Values.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim nv list", locals())


def delete(named_value_id, resource_group, service_name, yes=None):
    '''
    Delete an API Management Named Value.

    Required Parameters:
    - named_value_id -- Identifier of the NamedValue.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az apim nv delete", locals())


def show_secret(named_value_id, resource_group, service_name):
    '''
    Gets the secret of an API Management Named Value.

    Required Parameters:
    - named_value_id -- Identifier of the NamedValue.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim nv show-secret", locals())


def update(named_value_id, resource_group, service_name, add=None, force_string=None, if_match=None, remove=None, secret=None, set=None, tags=None, value=None):
    '''
    Update an API Management Named Value.

    Required Parameters:
    - named_value_id -- Identifier of the NamedValue.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- ETag of the Entity. Not required when creating an entity, but required when updating an entity.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - secret -- Determines whether the value is a secret and should be encrypted or not. Default value is false.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - value -- Required. Value of the NamedValue. Can contain policy expressions. It may not be empty or consist only of whitespace. This property will not be filled on GET operations! Use /listSecrets POST request to get the value.
    '''
    return _call_az("az apim nv update", locals())




'''
Manage and administer Azure Service Fabric clusters.
'''
from .. pyaz_utils import _call_az
from . import application_type, cluster, managed_application, managed_application_type, managed_cluster, managed_node_type, managed_service, service




from .... pyaz_utils import _call_az
from . import ip_config


def add(frontend_ip, gateway_name, name, resource_group, subnet, ip_address=None, no_wait=None, primary=None, subnet_prefix=None):
    '''
    Add a new Private Link with a default IP Configuration and associate it with an existing Frontend IP

    Required Parameters:
    - frontend_ip -- The frontend IP which the Private Link will associate to
    - gateway_name -- Name of the application gateway.
    - name -- The name of Private Link.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- The name or an existing ID of a subnet within the same vnet of an application gateway

    Optional Parameters:
    - ip_address -- The static private IP address of a subnet for Private Link. If omitting, a dynamic one will be created
    - no_wait -- Do not wait for the long-running operation to finish.
    - primary -- Whether the IP configuration is primary or not
    - subnet_prefix -- The CIDR prefix to use when creating a new subnet
    '''
    return _call_az("az network application-gateway private-link add", locals())


def remove(gateway_name, name, resource_group, no_wait=None, yes=None):
    '''
    Remove a Private Link and clear association with Frontend IP. The subnet associate with a Private Link might need to clear manually

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of Private Link.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network application-gateway private-link remove", locals())


def show(gateway_name, name, resource_group):
    '''
    Show a Private Link

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - name -- The name of Private Link.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway private-link show", locals())


def list(gateway_name, resource_group):
    '''
    List all the Private Link

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway private-link list", locals())


def wait(gateway_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until the condition of corresponding application gateway is met

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network application-gateway private-link wait", locals())




'''
Demos for designing, developing and demonstrating Azure CLI.
'''
from .. pyaz_utils import _call_az

def style(theme=None):
    '''
    A demo showing supported text styles.

    Optional Parameters:
    - theme -- The theme to format styled text. If unspecified, the default theme is used.
    '''
    return _call_az("az demo style", locals())




'''
Manage Data Lake Analytics jobs.
'''
from ... pyaz_utils import _call_az
from . import pipeline, recurrence


def submit(account, job_name, script, compile_mode=None, compile_only=None, degree_of_parallelism=None, pipeline_id=None, pipeline_name=None, pipeline_uri=None, priority=None, recurrence_id=None, recurrence_name=None, run_id=None, runtime_version=None):
    '''
    Submit a job to a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - job_name -- None
    - script -- The script to submit. This is either the script contents or use `@<file path>` to load the script from a file

    Optional Parameters:
    - compile_mode -- Indicates the type of compilation to be done on this job. Valid values are: 'Semantic' (Only performs semantic checks and necessary sanity checks), 'Full' (full compilation) and 'SingleBox' (Full compilation performed locally)
    - compile_only -- Indicates that the submission should only build the job and not execute if set to true.
    - degree_of_parallelism -- None
    - pipeline_id -- Job relationship pipeline GUID.
    - pipeline_name -- Friendly name of the job relationship pipeline.
    - pipeline_uri -- Unique pipeline URI which links to the originating service for this pipeline.
    - priority -- None
    - recurrence_id -- Recurrence GUID, unique per activity/script, regardless of iteration. Links different occurrences of the same job together.
    - recurrence_name -- Friendly recurrence nae for the correlation between jobs.
    - run_id -- GUID of the iteration of this pipeline.
    - runtime_version -- None
    '''
    return _call_az("az dla job submit", locals())


def wait(account, job_id, max_wait_time_sec=None, wait_interval_sec=None):
    '''
    Wait for a Data Lake Analytics job to finish.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - job_id -- None

    Optional Parameters:
    - max_wait_time_sec -- The maximum amount of time to wait before erroring out. Default value is to never timeout. Any value <= 0 means never timeout
    - wait_interval_sec -- The polling interval between checks for the job status, in seconds.
    '''
    return _call_az("az dla job wait", locals())


def show(account, job_identity):
    '''
    Get information for a Data Lake Analytics job.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - job_identity -- JobInfo ID.
    '''
    return _call_az("az dla job show", locals())


def cancel(account, job_identity):
    '''
    Cancel a Data Lake Analytics job.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - job_identity -- JobInfo ID to cancel.
    '''
    return _call_az("az dla job cancel", locals())


def list(account, name=None, pipeline_id=None, recurrence_id=None, result=None, state=None, submitted_after=None, submitted_before=None, submitter=None, top=None):
    '''
    List Data Lake Analytics jobs.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - name -- A filter which returns jobs only by the specified friendly name.
    - pipeline_id -- A filter which returns jobs only containing the specified pipeline_id.
    - recurrence_id -- A filter which returns jobs only containing the specified recurrence_id.
    - result -- A filter which returns jobs with only the specified result(s).
    - state -- A filter which returns jobs with only the specified state(s).
    - submitted_after -- A filter which returns jobs only submitted after the specified time, in ISO-8601 format.
    - submitted_before -- A filter which returns jobs only submitted before the specified time, in ISO-8601 format.
    - submitter -- A filter which returns jobs only by the specified submitter.
    - top -- Maximum number of items to return.
    '''
    return _call_az("az dla job list", locals())




'''
Manage shared access policies of a storage table.
'''
from .... pyaz_utils import _call_az

def create(name, table_name, account_key=None, account_name=None, connection_string=None, expiry=None, permissions=None, sas_token=None, start=None):
    '''
    

    Required Parameters:
    - name -- The stored access policy name.
    - table_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - expiry -- expiration UTC datetime in (Y-m-d'T'H:M:S'Z')
    - permissions -- Allowed values: (r)ead/query (a)dd (u)pdate (d)elete. Can be combined.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - start -- start UTC datetime (Y-m-d'T'H:M:S'Z'). Defaults to time of request.
    '''
    return _call_az("az storage table policy create", locals())


def delete(name, table_name, account_key=None, account_name=None, connection_string=None, sas_token=None):
    '''
    

    Required Parameters:
    - name -- The stored access policy name.
    - table_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage table policy delete", locals())


def show(name, table_name, account_key=None, account_name=None, connection_string=None, sas_token=None):
    '''
    

    Required Parameters:
    - name -- The stored access policy name.
    - table_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage table policy show", locals())


def list(table_name, account_key=None, account_name=None, connection_string=None, sas_token=None):
    '''
    

    Required Parameters:
    - table_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage table policy list", locals())


def update(name, table_name, account_key=None, account_name=None, connection_string=None, expiry=None, permissions=None, sas_token=None, start=None):
    '''
    

    Required Parameters:
    - name -- The stored access policy name.
    - table_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - expiry -- expiration UTC datetime in (Y-m-d'T'H:M:S'Z')
    - permissions -- Allowed values: (r)ead/query (a)dd (u)pdate (d)elete. Can be combined.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - start -- start UTC datetime (Y-m-d'T'H:M:S'Z'). Defaults to time of request.
    '''
    return _call_az("az storage table policy update", locals())




from .... pyaz_utils import _call_az

def create(gateway_name, name, public_cert_data, resource_group):
    '''
    Upload a root certificate.

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - name -- Root certificate name
    - public_cert_data -- Base64 contents of the root certificate file or file path.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway root-cert create", locals())


def delete(gateway_name, name, resource_group):
    '''
    Delete a root certificate.

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - name -- Root certificate name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway root-cert delete", locals())




'''
Manage marketplace agreement with marketplaceordering
'''
from .. pyaz_utils import _call_az

def show(plan, product, publisher):
    '''
    Get marketplace terms.

    Required Parameters:
    - plan -- Plan identifier string of image being deployed.
    - product -- Offeridentifier string of image being deployed.
    - publisher -- Publisher identifier string of image being deployed.
    '''
    return _call_az("az term show", locals())


def accept(plan, product, publisher):
    '''
    Accept marketplace terms.

    Required Parameters:
    - plan -- Plan identifier string of image being deployed.
    - product -- Offer identifier string of image being deployed.
    - publisher -- Publisher identifier string of image being deployed.
    '''
    return _call_az("az term accept", locals())




'''
Manage service principal owners.
'''
from .... pyaz_utils import _call_az

def list(id):
    '''
    List service principal owners.

    Required Parameters:
    - id -- service principal name, or object id or the service principal
    '''
    return _call_az("az ad sp owner list", locals())




from .... pyaz_utils import _call_az
from . import address, tunnel_interface


def create(lb_name, name, resource_group, backend_address=None, backend_addresses_config_file=None, vnet=None):
    '''
    Create an address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - backend_address -- None
    - backend_addresses_config_file -- None
    - vnet -- Name or Id of the virtual network applied to all backend addresses.
    '''
    return _call_az("az network lb address-pool create", locals())


def update(lb_name, name, resource_group, add=None, backend_address=None, backend_addresses_config_file=None, force_string=None, remove=None, set=None, vnet=None):
    '''
    Update an address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - backend_address -- None
    - backend_addresses_config_file -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - vnet -- Name or Id of the virtual network applied to all backend addresses.
    '''
    return _call_az("az network lb address-pool update", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of an address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb address-pool show", locals())


def list(lb_name, resource_group):
    '''
    List address pools.

    Required Parameters:
    - lb_name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb address-pool list", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete an address pool.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the backend address pool. If only one exists, omit to use as default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb address-pool delete", locals())




'''
Manage OAuth connection settings on a bot.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    Show all OAuth connection settings on a bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az bot authsetting list", locals())


def show(name, resource_group, setting_name):
    '''
    Show details of an OAuth connection setting on a bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - setting_name -- Name of the oauth connection setting.
    '''
    return _call_az("az bot authsetting show", locals())


def delete(name, resource_group, setting_name):
    '''
    Delete an OAuth connection setting on a bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - setting_name -- Name of the oauth connection setting.
    '''
    return _call_az("az bot authsetting delete", locals())


def create(client_id, client_secret, name, provider_scope_string, resource_group, service, setting_name, parameters=None):
    '''
    Create an OAuth connection setting on a bot.

    Required Parameters:
    - client_id -- Client ID associated with the service provider setting.
    - client_secret -- Client secret associated with the service provider setting.
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - provider_scope_string -- The scope string associated with the service provider setting.The string should be delimited as needed for the service provider.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service -- Name of the service provider. For a list of all service providers, use `az bot connection listserviceproviders`.
    - setting_name -- Name of the oauth connection setting.

    Optional Parameters:
    - parameters -- Parameter values for service provider parameters. Usage: --parameters key=value key1=value1.
    '''
    return _call_az("az bot authsetting create", locals())


def list_providers(provider_name=None):
    '''
    List details for all service providers available for creating OAuth connection settings.

    Optional Parameters:
    - provider_name -- Service provider name for which to fetch details.
    '''
    return _call_az("az bot authsetting list-providers", locals())




'''
Manage device streams of an IoT hub.
'''
from .... pyaz_utils import _call_az

def show(name, resource_group=None):
    '''
    Get IoT Hub's device streams endpoints.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub devicestream show", locals())




'''
billing balance
'''
from ... pyaz_utils import _call_az

def show(account_name, profile_name):
    '''
    The available credit balance for a billing profile. This is the balance that can be used for pay now to settle due or past due invoices. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing balance show", locals())




from ... pyaz_utils import _call_az

def list(workspace_name):
    '''
    List SQL scripts in a synapse workspace.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql-script list", locals())


def show(name, workspace_name):
    '''
    Get a SQL script.

    Required Parameters:
    - name -- The SQL script name
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql-script show", locals())


def delete(name, workspace_name, no_wait=None):
    '''
    Delete a SQL script.

    Required Parameters:
    - name -- The SQL script name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse sql-script delete", locals())


def create(file, name, workspace_name, additional_properties=None, description=None, folder_name=None, no_wait=None, result_limit=None, sql_database_name=None, sql_pool_name=None):
    '''
    Create or update a SQL script.

    Required Parameters:
    - file -- The SQL query file path
    - name -- The SQL script name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - additional_properties -- The SQL script additional properties
    - description -- The SQL script description
    - folder_name -- The folder that this SQL script is in. If not specified, this SQL script will appear at the root level. Eg: folder/subfolder1
    - no_wait -- Do not wait for the long-running operation to finish.
    - result_limit -- The SQL query results limit. Default is 5000. '-1' is no limit.
    - sql_database_name -- The SQL database name
    - sql_pool_name -- The SQL pool name
    '''
    return _call_az("az synapse sql-script create", locals())


def wait(name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a sql script is met.

    Required Parameters:
    - name -- The SQL script name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse sql-script wait", locals())


def export(output_folder, workspace_name, name=None):
    '''
    Export a SQL script.

    Required Parameters:
    - output_folder -- The SQL script export path
    - workspace_name -- The workspace name.

    Optional Parameters:
    - name -- The SQL script name
    '''
    return _call_az("az synapse sql-script export", locals())


def import_(file, name, workspace_name, additional_properties=None, description=None, folder_name=None, no_wait=None, result_limit=None, sql_database_name=None, sql_pool_name=None):
    '''
    Import a SQL script.

    Required Parameters:
    - file -- The SQL query file path
    - name -- The SQL script name
    - workspace_name -- The workspace name.

    Optional Parameters:
    - additional_properties -- The SQL script additional properties
    - description -- The SQL script description
    - folder_name -- The folder that this SQL script is in. If not specified, this SQL script will appear at the root level. Eg: folder/subfolder1
    - no_wait -- Do not wait for the long-running operation to finish.
    - result_limit -- The SQL query results limit. Default is 5000. '-1' is no limit.
    - sql_database_name -- The SQL database name
    - sql_pool_name -- The SQL pool name
    '''
    return _call_az("az synapse sql-script import", locals())




from ... pyaz_utils import _call_az

def list(control_name, standard_name):
    '''
    Get details and state of assessments mapped to selected regulatory compliance control.

    Required Parameters:
    - control_name -- The compliance control name
    - standard_name -- The compliance standard name
    '''
    return _call_az("az security regulatory-compliance-assessments list", locals())


def show(control_name, name, standard_name):
    '''
    Shows supported regulatory compliance details and state for selected assessment.

    Required Parameters:
    - control_name -- The compliance control name
    - name -- name of the resource to be fetched
    - standard_name -- The compliance standard name
    '''
    return _call_az("az security regulatory-compliance-assessments show", locals())




from ... pyaz_utils import _call_az

def list(resource_group, service_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search private-endpoint-connection list", locals())


def show(private_endpoint_connection_name, resource_group, service_name):
    '''
    

    Required Parameters:
    - private_endpoint_connection_name -- The name of the private endpoint connection to the Azure Cognitive Search service with the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    '''
    return _call_az("az search private-endpoint-connection show", locals())


def delete(private_endpoint_connection_name, resource_group, service_name, yes=None):
    '''
    

    Required Parameters:
    - private_endpoint_connection_name -- The name of the private endpoint connection to the Azure Cognitive Search service with the specified resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az search private-endpoint-connection delete", locals())


def update(actions_required, description, name, resource_group, service_name, status):
    '''
    

    Required Parameters:
    - actions_required -- Custom 'actions required' message when updating the private endpoint connection resource.
    - description -- Custom description when updating the private endpoint connection resource.
    - name -- Name of the private endpoint connection resource; for example: {the name of the private endpoint resource}.{guid}.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the search service.
    - status -- The updated status of the private endpoint connection resource. Possible values include: "Pending", "Approved", "Rejected", "Disconnected".
    '''
    return _call_az("az search private-endpoint-connection update", locals())




'''
Manage storage accounts.
'''
from ... pyaz_utils import _call_az
from . import sas_definition


def add(active_key_name, name, resource_id, vault_name, auto_regenerate_key=None, disabled=None, regeneration_period=None, tags=None):
    '''
    

    Required Parameters:
    - active_key_name -- Current active storage account key name.
    - name -- Name to identify the storage account in the vault.
    - resource_id -- Storage account resource id.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - auto_regenerate_key -- whether keyvault should manage the storage account for the user.
    - disabled -- Add the storage account in a disabled state.
    - regeneration_period -- The key regeneration time duration specified in ISO-8601 format, such as "P30D" for rotation every 30 days.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az keyvault storage add", locals())


def list(vault_name, maxresults=None):
    '''
    

    Required Parameters:
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    '''
    return _call_az("az keyvault storage list", locals())


def show(id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - id -- Id of the storage account.  If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage show", locals())


def update(active_key_name=None, auto_regenerate_key=None, disabled=None, id=None, name=None, regeneration_period=None, tags=None, vault_name=None):
    '''
    

    Optional Parameters:
    - active_key_name -- The current active storage account key name.
    - auto_regenerate_key -- whether keyvault should manage the storage account for the user.
    - disabled -- Add the storage account in a disabled state.
    - id -- Id of the storage account.  If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - regeneration_period -- The key regeneration time duration specified in ISO-8601 format, such as "P30D" for rotation every 30 days.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage update", locals())


def remove(id=None, name=None, vault_name=None):
    '''
    Remove a Key Vault managed Azure Storage Account and all associated SAS definitions. This operation requires the storage/delete permission.

    Optional Parameters:
    - id -- Id of the storage account.  If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage remove", locals())


def regenerate_key(key_name, id=None, name=None, vault_name=None):
    '''
    

    Required Parameters:
    - key_name -- The storage account key name.

    Optional Parameters:
    - id -- Id of the storage account.  If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage regenerate-key", locals())


def list_deleted(vault_name, maxresults=None):
    '''
    

    Required Parameters:
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    '''
    return _call_az("az keyvault storage list-deleted", locals())


def show_deleted(name, vault_name):
    '''
    

    Required Parameters:
    - name -- Name to identify the storage account in the vault.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault storage show-deleted", locals())


def purge(name, vault_name):
    '''
    

    Required Parameters:
    - name -- Name to identify the storage account in the vault.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault storage purge", locals())


def recover(name, vault_name):
    '''
    

    Required Parameters:
    - name -- Name to identify the storage account in the vault.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault storage recover", locals())


def backup(file, id=None, name=None, vault_name=None):
    '''
    

    Required Parameters:
    - file -- Local file path in which to store storage account backup.

    Optional Parameters:
    - id -- Id of the storage account.  If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage backup", locals())


def restore(file, vault_name):
    '''
    

    Required Parameters:
    - file -- Local key backup from which to restore storage account.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault storage restore", locals())




from ... pyaz_utils import _call_az

def list(resource_group=None):
    '''
    List all IoT Security solutions.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security iot-solution list", locals())


def show(resource_group, solution_name):
    '''
    Shows a IoT Security solution.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - solution_name -- Name of the IoT Security solution
    '''
    return _call_az("az security iot-solution show", locals())


def create(display_name, iot_hubs, location, resource_group, solution_name):
    '''
    Create your IoT Security solution.

    Required Parameters:
    - display_name -- Resource display name
    - iot_hubs -- IoT Hub resource IDs
    - location -- location of the resource
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - solution_name -- Name of the IoT Security solution
    '''
    return _call_az("az security iot-solution create", locals())


def delete(resource_group, solution_name):
    '''
    Delete your IoT Security solution.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - solution_name -- Name of the IoT Security solution
    '''
    return _call_az("az security iot-solution delete", locals())


def update(resource_group, solution_name, display_name=None, iot_hubs=None):
    '''
    Update your IoT Security solution.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - solution_name -- Name of the IoT Security solution

    Optional Parameters:
    - display_name -- Resource display name
    - iot_hubs -- IoT Hub resource IDs
    '''
    return _call_az("az security iot-solution update", locals())




'''
Manage sensitivity classification recommendations.
'''
from ...... pyaz_utils import _call_az

def list(name, resource_group, workspace_name, filter=None, included_disabled=None, skip_token=None):
    '''
    List the recommended sensitivity classifications of a given SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - filter -- An OData filter expression that filters elements in the collection.
    - included_disabled -- Indicates whether the result should include disabled recommendations
    - skip_token -- An OData query option to indicate how many elements to skip in the collection.
    '''
    return _call_az("az synapse sql pool classification recommendation list", locals())


def enable(column, name, resource_group, schema, table, workspace_name):
    '''
    Enable sensitivity recommendations for a given column(recommendations are enabled by default on all columns).

    Required Parameters:
    - column -- The name of column.
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of schema.
    - table -- The name of table.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool classification recommendation enable", locals())


def disable(column, name, resource_group, schema, table, workspace_name):
    '''
    Disable sensitivity recommendations for a given column(recommendations are enabled by default on all columns).

    Required Parameters:
    - column -- The name of column.
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of schema.
    - table -- The name of table.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool classification recommendation disable", locals())




'''
Manage file shares.
'''
from ... pyaz_utils import _call_az
from . import metadata, policy


def list(account_key=None, account_name=None, connection_string=None, include_metadata=None, include_snapshots=None, marker=None, num_results=None, prefix=None, sas_token=None, timeout=None):
    '''
    List the file shares in a storage account.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - include_metadata --  Specifies that share metadata be returned in the response.
    - include_snapshots --  Specifies that share snapshots be returned in the response.
    - marker --  An opaque continuation token. This value can be retrieved from the next_marker field of a previous generator object if num_results was specified and that generator has finished enumerating results. If specified, this generator will begin returning results from the point where the previous generator stopped.
    - num_results -- Specify the maximum number to return. If the request does not specify num_results, or specifies a value greater than 5000, the server will return up to 5000 items. Note that if the listing operation crosses a partition boundary, then the service will return a continuation token for retrieving the remaining of the results. Provide "*" to return all.
    - prefix --  Filters the results to return only shares whose names begin with the specified prefix.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share list", locals())


def create(name, account_key=None, account_name=None, connection_string=None, fail_on_exist=None, metadata=None, quota=None, sas_token=None, timeout=None):
    '''
    Creates a new share under the specified account.

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - fail_on_exist --  Specify whether to throw an exception when the share exists. False by default.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - quota --  Specifies the maximum size of the share, in gigabytes. Must be greater than 0, and less than or equal to 5TB (5120).
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share create", locals())


def delete(name, account_key=None, account_name=None, connection_string=None, delete_snapshots=None, fail_not_exist=None, sas_token=None, snapshot=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - delete_snapshots -- Specify the deletion strategy when the share has snapshots.
    - fail_not_exist --  Specify whether to throw an exception when the share doesn't exist. False by default.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable. Specify this argument to delete a specific snapshot only. delete_snapshots must be None if this is specified.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share delete", locals())


def generate_sas(name, account_key=None, account_name=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - cache_control --  Response header value for Cache-Control when resource is accessed using this shared access signature.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_disposition --  Response header value for Content-Disposition when resource is accessed using this shared access signature.
    - content_encoding --  Response header value for Content-Encoding when resource is accessed using this shared access signature.
    - content_language --  Response header value for Content-Language when resource is accessed using this shared access signature.
    - content_type --  Response header value for Content-Type when resource is accessed using this shared access signature.
    - expiry -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes invalid. Do not use if a stored access policy is referenced with --id that specifies this value.
    - https_only -- Only permit requests made with the HTTPS protocol. If omitted, requests from both the HTTP and HTTPS protocol are permitted.
    - ip -- Specifies the IP address or range of IP addresses from which to accept requests. Supports only IPv4 style addresses.
    - permissions -- The permissions the SAS grants. Allowed values: (d)elete (l)ist (r)ead (w)rite (d)elete (l)ist (r)ead (w)rite. Do not use if a stored access policy is referenced with --id that specifies this value. Can be combined.
    - policy_name -- The name of a stored access policy within the share's ACL.
    - start -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes valid. Do not use if a stored access policy is referenced with --id that specifies this value. Defaults to the time of the request.
    '''
    return _call_az("az storage share generate-sas", locals())


def stats(name, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share stats", locals())


def show(name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share show", locals())


def update(name, quota, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The file share name.
    - quota --  Specifies the maximum size of the share, in gigabytes. Must be greater than 0, and less than or equal to 5 TB (5120 GB).

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share update", locals())


def snapshot(name, account_key=None, account_name=None, connection_string=None, metadata=None, quota=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - quota --  Specifies the maximum size of the share, in gigabytes. Must be greater than 0, and less than or equal to 5TB (5120).
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share snapshot", locals())


def exists(name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Check for the existence of a file share.

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share exists", locals())


def url(name, account_key=None, account_name=None, connection_string=None, protocol=None, sas_token=None, unc=None):
    '''
    Create a URI to access a file share.

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - protocol -- Protocol to use.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - unc -- Output UNC network path.
    '''
    return _call_az("az storage share url", locals())


def list_handle(name, account_key=None, account_name=None, connection_string=None, marker=None, max_results=None, path=None, recursive=None, sas_token=None, snapshot=None, timeout=None):
    '''
    List file handles of a file share.

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - marker --  An opaque continuation token. This value can be retrieved from the next_marker field of a previous generator object if max_results was specified and that generator has finished enumerating results. If specified, this generator will begin returning results from the point where the previous generator stopped.
    - max_results --  Specifies the maximum number of handles taken on files and/or directories to return. If the request does not specify max_results or specifies a value greater than 5,000, the server will return up to 5,000 items. Setting max_results to a value less than or equal to zero results in error response code 400 (Bad Request).
    - path -- The path to the file within the file share.
    - recursive --  Boolean that specifies if operation should apply to the directory specified in the URI, its files, its subdirectories and their files.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share list-handle", locals())


def close_handle(name, account_key=None, account_name=None, close_all=None, connection_string=None, handle_id=None, marker=None, path=None, recursive=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Close file handles of a file share.

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - close_all -- Whether or not to close all the file handles. Specify close-all or a specific handle-id.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - handle_id -- Specifies handle ID opened on the file or directory to be closed. Astrix (‘*’) is a wildcard that specifies all handles.
    - marker -- An opaque continuation token. This value can be retrieved from the next_marker field of a previous generator object if it has not finished closing handles. If specified, this generator will begin closing handles from the point where the previous generator stopped.
    - path -- The path to the file within the file share.
    - recursive -- Boolean that specifies if operation should apply to the directory specified in the URI, its files, its subdirectories and their files.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot -- A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share close-handle", locals())




'''
Manage device with databoxedge
'''
from ... pyaz_utils import _call_az

def list(expand=None, resource_group=None):
    '''
    Get all the Data Box Edge/Data Box Gateway devices in a resource group or in a subscription.

    Optional Parameters:
    - expand -- Specify $expand=details to populate additional fields related to the resource or Specify $skipToken=<token> to populate the next page in the list.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge device list", locals())


def show(name, resource_group):
    '''
    Get the properties of the Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge device show", locals())


def create(name, resource_group, description=None, etag=None, friendly_name=None, location=None, model_description=None, no_wait=None, sku=None, status=None, tags=None):
    '''
    Create a Data Box Edge/Data Box Gateway resource.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - description -- The Description of the Data Box Edge/Gateway device.
    - etag -- The etag for the devices.
    - friendly_name -- The Data Box Edge/Gateway device name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - model_description -- The description of the Data Box Edge/Gateway device model.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku -- The SKU type.
    - status -- The status of the Data Box Edge/Gateway device.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az databoxedge device create", locals())


def update(name, resource_group, tags=None):
    '''
    Modify a Data Box Edge/Data Box Gateway resource.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az databoxedge device update", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete the Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az databoxedge device delete", locals())


def download_update(name, resource_group, no_wait=None):
    '''
    Download the updates on a Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az databoxedge device download-update", locals())


def install_update(name, resource_group, no_wait=None):
    '''
    Install the updates on the Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az databoxedge device install-update", locals())


def scan_for_update(name, resource_group, no_wait=None):
    '''
    Scan for updates on a Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az databoxedge device scan-for-update", locals())


def show_update_summary(name, resource_group):
    '''
    Get information about the availability of updates based on the last scan of the device. It also gets information about any ongoing download or install jobs on the device.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge device show-update-summary", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the databoxedge device is met.

    Required Parameters:
    - name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az databoxedge device wait", locals())




'''
Manage upstream settings.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    List upstream settings of an existing SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr upstream list", locals())


def update(name, resource_group, template):
    '''
    Update order sensitive upstream settings for an existing SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - template -- Template item for upstream settings. Use key=value pattern to set properties. Supported keys are "url-template", "hub-pattern", "event-pattern", "category-pattern".
    '''
    return _call_az("az signalr upstream update", locals())


def clear(name, resource_group):
    '''
    List upstream settings of an existing SignalR Service.

    Required Parameters:
    - name -- Name of signalr service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az signalr upstream clear", locals())




'''
Managed Identities for Task. Please see https://aka.ms/acr/tasks/task-create-managed-identity for more information.
'''
from .... pyaz_utils import _call_az

def assign(name, registry, identities=None, resource_group=None):
    '''
    Update the managed identity for a task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - identities -- Assigns managed identities to the task. Use '[system]' to refer to the system-assigned identity or a resource ID to refer to a user-assigned identity.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task identity assign", locals())


def remove(name, registry, identities=None, resource_group=None):
    '''
    Remove managed identities for a task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - identities -- Assigns managed identities to the task. Use '[system]' to refer to the system-assigned identity or a resource ID to refer to a user-assigned identity.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task identity remove", locals())


def show(name, registry, resource_group=None):
    '''
    Display the managed identities for task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task identity show", locals())




'''
Configure SSL certificates.
'''
from .... pyaz_utils import _call_az

def upload(certificate_file, certificate_password, name, resource_group, slot=None):
    '''
    Upload an SSL certificate to a function app.

    Required Parameters:
    - certificate_file -- The filepath for the .pfx file
    - certificate_password -- The ssl cert password
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- The name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp config ssl upload", locals())


def list(resource_group):
    '''
    List SSL certificates for a function app.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp config ssl list", locals())


def show(certificate_name, resource_group):
    '''
    Show the details of an SSL certificate for a function app.

    Required Parameters:
    - certificate_name -- The name of the certificate
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp config ssl show", locals())


def bind(certificate_thumbprint, name, resource_group, ssl_type, slot=None):
    '''
    Bind an SSL certificate to a function app.

    Required Parameters:
    - certificate_thumbprint -- The ssl cert thumbprint
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - ssl_type -- The ssl cert type

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp config ssl bind", locals())


def unbind(certificate_thumbprint, name, resource_group, slot=None):
    '''
    Unbind an SSL certificate from a function app.

    Required Parameters:
    - certificate_thumbprint -- The ssl cert thumbprint
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp config ssl unbind", locals())


def delete(certificate_thumbprint, resource_group):
    '''
    Delete an SSL certificate from a function app.

    Required Parameters:
    - certificate_thumbprint -- The ssl cert thumbprint
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp config ssl delete", locals())


def import_(key_vault, key_vault_certificate_name, name, resource_group):
    '''
    Import an SSL certificate to a function app from Key Vault.

    Required Parameters:
    - key_vault -- The name or resource ID of the Key Vault
    - key_vault_certificate_name -- The name of the certificate in Key Vault
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp config ssl import", locals())


def create(hostname, name, resource_group, slot=None):
    '''
    Create a Managed Certificate for a hostname in a function app.

    Required Parameters:
    - hostname -- The custom domain name
    - name -- Name of the web app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp config ssl create", locals())




'''
Manage Data Lake Store accounts.
'''
from ... pyaz_utils import _call_az
from . import firewall, network_rule, trusted_provider


def create(account, default_group=None, disable_encryption=None, encryption_type=None, key_name=None, key_vault_id=None, key_version=None, location=None, resource_group=None, tags=None, tier=None):
    '''
    Creates a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.

    Optional Parameters:
    - default_group -- Name of the default group to give permissions to for freshly created files and folders in the Data Lake Store account.
    - disable_encryption -- Indicates that the account will not have any form of encryption applied to it.
    - encryption_type -- Indicates what type of encryption to provision the account with. By default, encryption is ServiceManaged. If no encryption is desired, it must be explicitly set with the --disable-encryption flag.
    - key_name -- None
    - key_vault_id -- None
    - key_version -- Key version for the user-assigned encryption type.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The desired commitment tier for this account to use.
    '''
    return _call_az("az dls account create", locals())


def update(account, allow_azure_ips=None, default_group=None, firewall_state=None, key_version=None, resource_group=None, tags=None, tier=None, trusted_id_provider_state=None):
    '''
    Updates a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.

    Optional Parameters:
    - allow_azure_ips -- Allow/block Azure originating IPs through the firewall
    - default_group -- Name of the default group to give permissions to for freshly created files and folders in the Data Lake Store account.
    - firewall_state -- Enable/disable existing firewall rules.
    - key_version -- Key version for the user-assigned encryption type.
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The desired commitment tier for this account to use.
    - trusted_id_provider_state -- Enable/disable the existing trusted ID providers.
    '''
    return _call_az("az dls account update", locals())


def list(resource_group=None):
    '''
    Lists available Data Lake Store accounts.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az dls account list", locals())


def delete(account, resource_group=None):
    '''
    Delete a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account delete", locals())


def show(account, resource_group=None):
    '''
    Get the details of a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account show", locals())


def enable_key_vault(account, resource_group=None):
    '''
    Enable the use of Azure Key Vault for encryption of a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account enable-key-vault", locals())




'''
Manage user credentials for deployment.
'''
from .... pyaz_utils import _call_az

def set(user_name, password=None):
    '''
    Update deployment credentials.

    Required Parameters:
    - user_name -- user name

    Optional Parameters:
    - password -- password, will prompt if not specified
    '''
    return _call_az("az functionapp deployment user set", locals())


def show():
    return _call_az("az functionapp deployment user show", locals())




from ... pyaz_utils import _call_az

def create(name, parameters, resource_group):
    '''
    

    Required Parameters:
    - name -- The autoscale setting name.
    - parameters -- JSON encoded parameters configuration. Use @{file} to load from a file. Use az autoscale-settings get-parameters-template to export json template.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale-settings create", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The autoscale setting name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale-settings delete", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The autoscale setting name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale-settings show", locals())


def list(resource_group):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor autoscale-settings list", locals())


def get_parameters_template():
    return _call_az("az monitor autoscale-settings get-parameters-template", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Updates an autoscale setting.

    Required Parameters:
    - name -- The autoscale setting name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az monitor autoscale-settings update", locals())




from .... pyaz_utils import _call_az
from . import delete_policy


def show(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob service-properties show", locals())


def update(404_document=None, account_key=None, account_name=None, add=None, auth_mode=None, connection_string=None, delete_retention=None, delete_retention_period=None, force_string=None, index_document=None, remove=None, sas_token=None, set=None, static_website=None, timeout=None):
    '''
    Update storage blob service properties.

    Optional Parameters:
    - 404_document -- Represents the path to the error document that should be shown when an error 404 is issued, in other words, when a browser requests a page that does not exist.
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - delete_retention -- Enables soft-delete.
    - delete_retention_period -- Number of days that soft-deleted blob will be retained. Must be in range [1,365].
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - index_document -- Represents the name of the index document. This is commonly "index.html".
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - static_website -- Enables static-website.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob service-properties update", locals())




from ... pyaz_utils import call_az

def create(allow_force_push=None, functionapp_name=None, github_pat=None, github_repository=None, organization_name=None, overwrite_yaml=None, project_name=None, repository_name=None):
    'Create an Azure DevOps pipeline for a function app.'
    return call_az("az functionapp devops-pipeline create", locals())




'''
Manage the durability of a cluster.
'''
from .... pyaz_utils import _call_az

def update(cluster_name, durability_level, node_type, resource_group):
    '''
    Update the durability tier or VM SKU of a node type in the cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - durability_level -- durability level.
    - node_type -- the Node type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf cluster durability update", locals())




'''
Manage Azure IoT hubs.
'''
from ... pyaz_utils import _call_az
from . import certificate, consumer_group, devicestream, identity, message_enrichment, policy, route, routing_endpoint


def create(name, resource_group, c2d_max_delivery_count=None, c2d_ttl=None, disable_device_sas=None, disable_local_auth=None, disable_module_sas=None, feedback_lock_duration=None, feedback_max_delivery_count=None, feedback_ttl=None, fileupload_notification_lock_duration=None, fileupload_notification_max_delivery_count=None, fileupload_notification_ttl=None, fileupload_notifications=None, fileupload_sas_ttl=None, fileupload_storage_auth_type=None, fileupload_storage_connectionstring=None, fileupload_storage_container_name=None, fileupload_storage_container_uri=None, fileupload_storage_identity=None, location=None, mi_system_assigned=None, mi_user_assigned=None, min_tls_version=None, partition_count=None, retention_day=None, role=None, scopes=None, sku=None, tags=None, unit=None):
    '''
    Create an Azure IoT hub.

    Required Parameters:
    - name -- IoT Hub name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - c2d_max_delivery_count -- The number of times the IoT hub will attempt to deliver a cloud-to-device message to a device, between 1 and 100.
    - c2d_ttl -- The amount of time a message is available for the device to consume before it is expired by IoT Hub, between 1 and 48 hours.
    - disable_device_sas -- A boolean indicating whether or not to disable all device (including Edge devices but excluding modules) scoped SAS keys for authentication
    - disable_local_auth -- A boolean indicating whether or not to disable IoT hub scoped SAS keys for authentication.
    - disable_module_sas -- A boolean indicating whether or not to disable module-scoped SAS keys for authentication.
    - feedback_lock_duration -- The lock duration for the feedback queue, between 5 and 300 seconds.
    - feedback_max_delivery_count -- The number of times the IoT hub attempts to deliver a message on the feedback queue, between 1 and 100.
    - feedback_ttl -- The period of time for which the IoT hub will maintain the feedback for expiration or delivery of cloud-to-device messages, between 1 and 48 hours.
    - fileupload_notification_lock_duration -- The lock duration for the file upload notifications queue, between 5 and 300 seconds.
    - fileupload_notification_max_delivery_count -- The number of times the IoT hub will attempt to deliver a file notification message, between 1 and 100.
    - fileupload_notification_ttl -- The amount of time a file upload notification is available for the service to consume before it is expired by IoT Hub, between 1 and 48 hours.
    - fileupload_notifications -- A boolean indicating whether to log information about uploaded files to the messages/servicebound/filenotifications IoT Hub endpoint.
    - fileupload_sas_ttl -- The amount of time a SAS URI generated by IoT Hub is valid before it expires, between 1 and 24 hours.
    - fileupload_storage_auth_type -- The authentication type for the Azure Storage account to which files are uploaded.
    - fileupload_storage_connectionstring -- The connection string for the Azure Storage account to which files are uploaded.
    - fileupload_storage_container_name -- The name of the root container where you upload files. The container need not exist but should be creatable using the connectionString specified.
    - fileupload_storage_container_uri -- The container URI for the Azure Storage account to which files are uploaded.
    - fileupload_storage_identity -- The managed identity to use for file upload authentication. Use '[system]' to refer to the system-assigned managed identity or a resource ID to refer to a user-assigned managed identity.
    - location -- Location of your IoT Hub. Default is the location of target resource group.
    - mi_system_assigned -- Enable system-assigned managed identity for this hub
    - mi_user_assigned -- Enable user-assigned managed identities for this hub. Accept space-separated list of identity resource IDs.
    - min_tls_version -- Specify the minimum TLS version to support for this hub. Can be set to "1.2" to have clients that use a TLS version below 1.2 to be rejected.
    - partition_count -- The number of partitions of the backing Event Hub for device-to-cloud messages.
    - retention_day -- Specifies how long this IoT hub will maintain device-to-cloud events, between 1 and 7 days.
    - role -- Role to assign to the hub's system-assigned managed identity.
    - scopes -- Space separated list of scopes to assign the role (--role) for the system-assigned managed identity.
    - sku -- Pricing tier for Azure IoT Hub. Note that only one free IoT hub instance (F1) is allowed in each subscription. Exception will be thrown if free instances exceed one.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - unit -- Units in your IoT Hub.
    '''
    return _call_az("az iot hub create", locals())


def list(resource_group=None):
    '''
    List IoT hubs.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub list", locals())


def show_connection_string(all=None, hub_name=None, key=None, policy_name=None, resource_group=None):
    '''
    Show the connection strings for an IoT hub.

    Optional Parameters:
    - all -- Allow to show all shared access policies.
    - hub_name -- IoT Hub name.
    - key -- The key to use.
    - policy_name -- Shared access policy to use.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub show-connection-string", locals())


def show(name, resource_group=None):
    '''
    Get the details of an IoT hub.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub show", locals())


def update(name, add=None, c2d_max_delivery_count=None, c2d_ttl=None, disable_device_sas=None, disable_local_auth=None, disable_module_sas=None, feedback_lock_duration=None, feedback_max_delivery_count=None, feedback_ttl=None, fileupload_notification_lock_duration=None, fileupload_notification_max_delivery_count=None, fileupload_notification_ttl=None, fileupload_notifications=None, fileupload_sas_ttl=None, fileupload_storage_auth_type=None, fileupload_storage_connectionstring=None, fileupload_storage_container_name=None, fileupload_storage_container_uri=None, fileupload_storage_identity=None, force_string=None, remove=None, resource_group=None, retention_day=None, set=None, sku=None, tags=None, unit=None):
    '''
    Update metadata for an IoT hub.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - c2d_max_delivery_count -- The number of times the IoT hub will attempt to deliver a cloud-to-device message to a device, between 1 and 100.
    - c2d_ttl -- The amount of time a message is available for the device to consume before it is expired by IoT Hub, between 1 and 48 hours.
    - disable_device_sas -- A boolean indicating whether or not to disable all device (including Edge devices but excluding modules) scoped SAS keys for authentication
    - disable_local_auth -- A boolean indicating whether or not to disable IoT hub scoped SAS keys for authentication.
    - disable_module_sas -- A boolean indicating whether or not to disable module-scoped SAS keys for authentication.
    - feedback_lock_duration -- The lock duration for the feedback queue, between 5 and 300 seconds.
    - feedback_max_delivery_count -- The number of times the IoT hub attempts to deliver a message on the feedback queue, between 1 and 100.
    - feedback_ttl -- The period of time for which the IoT hub will maintain the feedback for expiration or delivery of cloud-to-device messages, between 1 and 48 hours.
    - fileupload_notification_lock_duration -- The lock duration for the file upload notifications queue, between 5 and 300 seconds.
    - fileupload_notification_max_delivery_count -- The number of times the IoT hub will attempt to deliver a file notification message, between 1 and 100.
    - fileupload_notification_ttl -- The amount of time a file upload notification is available for the service to consume before it is expired by IoT Hub, between 1 and 48 hours.
    - fileupload_notifications -- A boolean indicating whether to log information about uploaded files to the messages/servicebound/filenotifications IoT Hub endpoint.
    - fileupload_sas_ttl -- The amount of time a SAS URI generated by IoT Hub is valid before it expires, between 1 and 24 hours.
    - fileupload_storage_auth_type -- The authentication type for the Azure Storage account to which files are uploaded.
    - fileupload_storage_connectionstring -- The connection string for the Azure Storage account to which files are uploaded.
    - fileupload_storage_container_name -- The name of the root container where you upload files. The container need not exist but should be creatable using the connectionString specified.
    - fileupload_storage_container_uri -- The container URI for the Azure Storage account to which files are uploaded.
    - fileupload_storage_identity -- The managed identity to use for file upload authentication. Use '[system]' to refer to the system-assigned managed identity or a resource ID to refer to a user-assigned managed identity.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - retention_day -- Specifies how long this IoT hub will maintain device-to-cloud events, between 1 and 7 days.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- Pricing tier for Azure IoT Hub. Note that only one free IoT hub instance (F1) is allowed in each subscription. Exception will be thrown if free instances exceed one.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - unit -- Units in your IoT Hub.
    '''
    return _call_az("az iot hub update", locals())


def delete(name, resource_group=None):
    '''
    Delete an IoT hub.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub delete", locals())


def list_skus(name, resource_group=None):
    '''
    List available pricing tiers.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub list-skus", locals())


def show_quota_metrics(name, resource_group=None):
    '''
    Get the quota metrics for an IoT hub.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub show-quota-metrics", locals())


def show_stats(name, resource_group=None):
    '''
    Get the statistics for an IoT hub.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub show-stats", locals())


def manual_failover(name, no_wait=None, resource_group=None):
    '''
    Initiate a manual failover for the IoT Hub to the geo-paired disaster recovery region.

    Required Parameters:
    - name -- IoT Hub name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot hub manual-failover", locals())




'''
Manage Azure API Management Product's APIs.
'''
from .... pyaz_utils import _call_az

def list(product_id, resource_group, service_name):
    '''
    Lists a collection of the APIs associated with a product.

    Required Parameters:
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance
    '''
    return _call_az("az apim product api list", locals())


def check(api_id, product_id, resource_group, service_name):
    '''
    Checks that API entity specified by identifier is associated with the Product entity.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance
    '''
    return _call_az("az apim product api check", locals())


def add(api_id, product_id, resource_group, service_name):
    '''
    Add an API to the specified product.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance
    '''
    return _call_az("az apim product api add", locals())


def delete(api_id, product_id, resource_group, service_name):
    '''
    Deletes the specified API from the specified product.

    Required Parameters:
    - api_id -- API revision identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - product_id -- Product identifier. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the api management service instance
    '''
    return _call_az("az apim product api delete", locals())




'''
Manage near-realtime metric alert rules.
'''
from .... pyaz_utils import _call_az
from . import condition, dimension


def create(condition, name, resource_group, scopes, action=None, auto_mitigate=None, description=None, disabled=None, evaluation_frequency=None, severity=None, tags=None, target_resource_region=None, target_resource_type=None, window_size=None):
    '''
    Create a metric-based alert rule.

    Required Parameters:
    - condition -- None
    - name -- Name of the alert rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scopes -- Space-separated list of scopes the rule applies to. The resources specified in this parameter must be of the same type and exist in the same location.

    Optional Parameters:
    - action -- None
    - auto_mitigate -- Automatically resolve the alert.
    - description -- Free-text description of the rule.
    - disabled -- None
    - evaluation_frequency -- Frequency with which to evaluate the rule in "##h##m##s" format.
    - severity -- Severity of the alert from 0 (critical) to 4 (verbose).
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_resource_region -- The region of the target resource(s) in scopes. This must be provided when scopes is resource group or subscription.
    - target_resource_type -- The resource type of the target resource(s) in scopes. This must be provided when scopes is resource group or subscription.
    - window_size -- Time over which to aggregate metrics in "##h##m##s" format.
    '''
    return _call_az("az monitor metrics alert create", locals())


def delete(name, resource_group):
    '''
    Delete a metrics-based alert rule.

    Required Parameters:
    - name -- Name of the alert rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor metrics alert delete", locals())


def list(resource_group=None):
    '''
    List metric-based alert rules.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor metrics alert list", locals())


def show(name, resource_group):
    '''
    Show a metrics-based alert rule.

    Required Parameters:
    - name -- Name of the alert rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az monitor metrics alert show", locals())


def update(name, resource_group, add=None, add_action=None, add_condition=None, auto_mitigate=None, description=None, enabled=None, evaluation_frequency=None, force_string=None, remove=None, remove_actions=None, remove_conditions=None, scopes=None, set=None, severity=None, tags=None, window_size=None):
    '''
    Update a metric-based alert rule.

    Required Parameters:
    - name -- Name of the alert rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - add_action -- None
    - add_condition -- None
    - auto_mitigate -- Automatically resolve the alert.
    - description -- Free-text description of the rule.
    - enabled -- Whether the metric alert rule is enabled.
    - evaluation_frequency -- Frequency with which to evaluate the rule in "##h##m##s" format.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - remove_actions -- None
    - remove_conditions -- None
    - scopes -- Space-separated list of scopes the rule applies to. The resources specified in this parameter must be of the same type and exist in the same location.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - severity -- Severity of the alert from 0 (critical) to 4 (verbose).
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - window_size -- Time over which to aggregate metrics in "##h##m##s" format.
    '''
    return _call_az("az monitor metrics alert update", locals())




from .. pyaz_utils import _call_az

def create(key_url, name, resource_group, source_vault, enable_auto_key_rotation=None, encryption_type=None, location=None, no_wait=None, tags=None):
    '''
    Create a disk encryption set.

    Required Parameters:
    - key_url -- URL pointing to a key or secret in KeyVault.
    - name -- Name of disk encryption set.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_vault -- Name or ID of the KeyVault containing the key or secret.

    Optional Parameters:
    - enable_auto_key_rotation -- Enable automatic rotation of keys.
    - encryption_type -- The type of key used to encrypt the data of the disk. EncryptionAtRestWithPlatformKey: Disk is encrypted at rest with Platform managed key. It is the default encryption type. EncryptionAtRestWithCustomerKey: Disk is encrypted at rest with Customer managed key that can be changed and revoked by a customer. EncryptionAtRestWithPlatformAndCustomerKeys: Disk is encrypted at rest with 2 layers of encryption. One of the keys is Customer managed and the other key is Platform managed.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az disk-encryption-set create", locals())


def delete(name, resource_group):
    '''
    Delete a disk encryption set.

    Required Parameters:
    - name -- Name of disk encryption set.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az disk-encryption-set delete", locals())


def update(name, resource_group, add=None, enable_auto_key_rotation=None, force_string=None, key_url=None, remove=None, set=None, source_vault=None):
    '''
    Update a disk encryption set.

    Required Parameters:
    - name -- Name of disk encryption set.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - enable_auto_key_rotation -- Enable automatic rotation of keys.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - key_url -- URL pointing to a key or secret in KeyVault.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - source_vault -- Name or ID of the KeyVault containing the key or secret.
    '''
    return _call_az("az disk-encryption-set update", locals())


def show(name, resource_group):
    '''
    Get information of a disk encryption sets.

    Required Parameters:
    - name -- Name of disk encryption set.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az disk-encryption-set show", locals())


def list(resource_group=None):
    '''
    List disk encryption sets.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az disk-encryption-set list", locals())


def list_associated_resources(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of disk encryption set.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az disk-encryption-set list-associated-resources", locals())




'''
Online storage entity in Azure used to hold data such as backup copies, recovery points and backup policies.
'''
from ... pyaz_utils import _call_az
from . import backup_properties, encryption, identity


def create(location, name, resource_group, tags=None):
    '''
    Create a new Recovery Services vault.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az backup vault create", locals())


def show(name, resource_group):
    '''
    Show details of a particular Recovery service vault.

    Required Parameters:
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az backup vault show", locals())


def list(resource_group=None):
    '''
    List Recovery service vaults within a subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az backup vault list", locals())


def delete(name, resource_group, force=None, yes=None):
    '''
    Delete an existing Recovery services vault.

    Required Parameters:
    - name -- Name of the Recovery services vault.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force -- Force completion of the requested action.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az backup vault delete", locals())

